'use client';
import React from "react";
import { Modal, Text, Loader } from "@mantine/core";
 
type StatementItem = {
  date: string;
  type: string;
  amount: number;
};
 
interface StatementModalProps {
  opened: boolean;
  onClose: () => void;
  loading: boolean;
  error: string;
  data: StatementItem[] | null;
}
 
const StatementModal: React.FC<StatementModalProps> = ({
  opened,
  onClose,
  loading,
  error,
  data,
}) => {
  return (
    <Modal opened={opened} onClose={onClose} title="Account Statement" size="lg">
      {loading && <Loader />}
      {error && <Text c="red">{error}</Text>}
 
      {!loading && !error && data && data.length > 0 && (
        <div>
          {data.map((item, index) => (
            <div key={index} style={{ marginBottom: 10 }}>
              <Text>Date: {item.date}</Text>
              <Text>Type: {item.type}</Text>
              <Text>Amount: ₹{item.amount}</Text>
            </div>
          ))}
        </div>
      )}
 
      {!loading && !error && data && data.length === 0 && (
        <Text>No transactions found.</Text>
      )}
    </Modal>
  );
};
 
export default StatementModal;
 